@@ -24,7 +24,7 @@ class Experiment(_MLflowObject):
         num_runs=None,
         num_user_collaborators=None,
         description=None,
-        privacy_type=None,
+        privacy_type=PrivacyType.PRIVATE,
     ):
         super().__init__()
         self._experiment_id = experiment_id
