@@ -51,6 +51,8 @@ class RunInfo(_MLflowObject):
         artifact_uri=None,
         run_id=None,
         name="",
+        fqn="",
+        description=None,
     ):
         if run_uuid is None:
             raise Exception("run_uuid cannot be None")
@@ -75,6 +77,8 @@ class RunInfo(_MLflowObject):
         self._lifecycle_stage = lifecycle_stage
         self._artifact_uri = artifact_uri
         self._name = name
+        self._fqn = fqn
+        self._description = description
 
     def __eq__(self, other):
         if type(other) is type(self):
@@ -144,6 +148,14 @@ class RunInfo(_MLflowObject):
     def name(self):
         return self._name
 
+    @searchable_attribute
+    def fqn(self):
+        return self._fqn
+
+    @property
+    def description(self):
+        return self._description
+
     def to_proto(self):
         proto = ProtoRunInfo()
         proto.run_uuid = self.run_uuid
@@ -158,6 +170,8 @@ class RunInfo(_MLflowObject):
             proto.artifact_uri = self.artifact_uri
         proto.lifecycle_stage = self.lifecycle_stage
         proto.name = self.name or ""
+        proto.fqn = self.fqn
+        proto.description = self.description or ""
         return proto
 
     @classmethod
@@ -178,6 +192,8 @@ class RunInfo(_MLflowObject):
             lifecycle_stage=proto.lifecycle_stage,
             artifact_uri=proto.artifact_uri,
             name=proto.name,
+            fqn=proto.fqn,
+            description=proto.description,
         )
 
     @classmethod
