@@ -363,9 +363,15 @@ class RestStore(AbstractStore):
         return RunLog.from_proto(response_proto.run_log)
 
     def list_run_logs(
-        self, run_uuid: str, key: typing.Optional[str] = None, log_type: typing.Optional[str] = None
+        self,
+        run_uuid: str,
+        key: typing.Optional[str] = None,
+        log_type: typing.Optional[str] = None,
+        steps: typing.Optional[typing.List[int]] = None,
     ) -> typing.List[RunLog]:
-        request_body_proto = ListRunLogs(run_uuid=run_uuid, key=key or "", log_type=log_type or "")
+        request_body_proto = ListRunLogs(
+            run_uuid=run_uuid, key=key or "", log_type=log_type or "", steps=steps or []
+        )
         request_body = message_to_json(request_body_proto)
         response_proto = self._call_endpoint(ListRunLogs, request_body)
         return [RunLog.from_proto(run_log) for run_log in response_proto.run_logs]
