@@ -25,6 +25,7 @@ _BAD_CHARACTERS_MESSAGE = (
     " spaces ( ), and slashes (/)."
 )
 _EXPERIMENT_NAME_REGEX = re.compile(r"^[a-zA-Z0-9-]*$")
+_RUN_NAME_REGEX = re.compile(r"^[a-zA-Z0-9-]*$")
 _RUN_LOG_LOG_TYPE_REGEX = re.compile(r"^[a-zA-Z0-9-/]*$")
 _RUN_LOG_KEY_REGEX = re.compile(r"^[a-zA-Z0-9-_]*$")
 
@@ -44,6 +45,8 @@ MAX_USER_EMAIL_LENGTH = 64
 MAX_TEAM_NAME_LENGTH = 64
 MAX_RUN_LOG_KEY_NAME_LENGTH = 128
 MAX_RUN_LOG_LOG_TYPE_LENGTH = 128
+MAX_EXPERIMENT_DESCRIPTION_LENGTH = 512
+MAX_RUN_DESCRIPTION_LENGTH = 512
 
 _UNSUPPORTED_DB_TYPE_MSG = "Supported database engines are {%s}" % ", ".join(DATABASE_ENGINES)
 
@@ -104,9 +107,10 @@ def _validate_metric_name(name):
 
 def _validate_run_name(name):
     _validate_length_limit("Run name", MAX_ENTITY_KEY_LENGTH, name)
-    if name is None or not _VALID_PARAM_AND_METRIC_NAMES.match(name):
+    if not name or not _RUN_NAME_REGEX.match(name):
         raise MlflowException(
-            "Invalid run  name: '%s'. %s" % (name, _BAD_CHARACTERS_MESSAGE),
+            f"Invalid run name {name} . Name should not empty string"
+            " may only contain alphanumerics or dashes (-)",
             INVALID_PARAMETER_VALUE,
         )
 
@@ -425,3 +429,11 @@ def _validate_team_name(team_name):
     _validate_length_limit("Team Name", MAX_TEAM_NAME_LENGTH, team_name)
     if team_name is None or team_name == "":
         raise MlflowException(f"Invalid Team Name: {team_name}", INVALID_PARAMETER_VALUE)
+
+
+def _validate_experiment_description(description):
+    _validate_length_limit("Experiment Description", MAX_EXPERIMENT_DESCRIPTION_LENGTH, description)
+
+
+def _validate_run_description(description):
+    _validate_length_limit("Run Description", MAX_RUN_DESCRIPTION_LENGTH, description)
